# coding: utf-8

"""
    Moodle Webservice API

    Auto-generated OpenAPI spec for Moodle's Webservice API.

    The version of the OpenAPI document: 4.5.7 (Build: 20251006)
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


from __future__ import annotations
import pprint
import re  # noqa: F401
import json

from pydantic import BaseModel, ConfigDict, Field, StrictInt, StrictStr
from typing import Any, ClassVar, Dict, List, Optional
from typing import Optional, Set
from typing_extensions import Self

from poodle_async_mini.configuration import settings

class CoreCommentAddCommentsParametersCommentsInner(BaseModel):
    """
    CoreCommentAddCommentsParametersCommentsInner
    """ # noqa: E501
    area: Optional[StrictStr] = Field(default='', description="string comment area")
    component: Optional[StrictStr] = Field(description="component")
    content: Optional[StrictStr] = Field(description="component")
    contextlevel: Optional[StrictStr] = Field(description="contextlevel system, course, user...")
    instanceid: Optional[StrictInt] = Field(description="the id of item associated with the contextlevel")
    itemid: Optional[StrictInt] = Field(description="associated id")
    __properties: ClassVar[List[str]] = ["area", "component", "content", "contextlevel", "instanceid", "itemid"]

    model_config = ConfigDict(
        populate_by_name=True,
        validate_assignment=True,
        protected_namespaces=(),
    )


    def to_str(self) -> str:
        """Returns the string representation of the model using alias"""
        return pprint.pformat(self.model_dump(by_alias=True))

    def to_json(self) -> str:
        """Returns the JSON representation of the model using alias"""
        # TODO: pydantic v2: use .model_dump_json(by_alias=True, exclude_unset=True) instead
        return json.dumps(self.to_dict())

    @classmethod
    def from_json(cls, json_str: str) -> Optional[Self]:
        """Create an instance of CoreCommentAddCommentsParametersCommentsInner from a JSON string"""
        return cls.from_dict(json.loads(json_str))

    def to_dict(self) -> Dict[str, Any]:
        """Return the dictionary representation of the model using alias.

        This has the following differences from calling pydantic's
        `self.model_dump(by_alias=True)`:

        * `None` is only added to the output dict for nullable fields that
          were set at model initialization. Other fields with value `None`
          are ignored.
        """
        excluded_fields: Set[str] = set([
        ])

        _dict = self.model_dump(
            by_alias=True,
            exclude=excluded_fields,
            exclude_none=True,
        )
        # set to None if area (nullable) is None
        # and model_fields_set contains the field
        if self.area is None and "area" in self.model_fields_set:
            _dict['area'] = None

        # set to None if component (nullable) is None
        # and model_fields_set contains the field
        if self.component is None and "component" in self.model_fields_set:
            _dict['component'] = None

        # set to None if content (nullable) is None
        # and model_fields_set contains the field
        if self.content is None and "content" in self.model_fields_set:
            _dict['content'] = None

        # set to None if contextlevel (nullable) is None
        # and model_fields_set contains the field
        if self.contextlevel is None and "contextlevel" in self.model_fields_set:
            _dict['contextlevel'] = None

        # set to None if instanceid (nullable) is None
        # and model_fields_set contains the field
        if self.instanceid is None and "instanceid" in self.model_fields_set:
            _dict['instanceid'] = None

        # set to None if itemid (nullable) is None
        # and model_fields_set contains the field
        if self.itemid is None and "itemid" in self.model_fields_set:
            _dict['itemid'] = None

        return _dict

    @classmethod
    def from_dict(cls, obj: Optional[Dict[str, Any]]) -> Optional[Self]:
        """Create an instance of CoreCommentAddCommentsParametersCommentsInner from a dict"""
        if obj is None:
            return None

        relaxed = settings.relaxe_all_models or "CoreCommentAddCommentsParametersCommentsInner" in settings.relaxed_models

        if not isinstance(obj, dict):
            return cls.model_construct(**obj) if relaxed else cls.model_validate(obj)

        data = {
            "area": obj.get("area") if obj.get("area") is not None else '',
            "component": obj.get("component"),
            "content": obj.get("content"),
            "contextlevel": obj.get("contextlevel"),
            "instanceid": obj.get("instanceid"),
            "itemid": obj.get("itemid")
        }
        _obj = cls.model_construct(**data) if relaxed else cls.model_validate(data)
        return _obj


